@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,8 @@
 
 # Std Lib
 import sys
-import os, os.path
+import os
+import os.path
 import ConfigParser
 import locale
 import pwd
@@ -165,13 +166,6 @@ except ValueError:
     
 prop.version = sys_cfg.hplip.version or 'x.x.x'
 prop.home_dir = sys_cfg.dirs.home or os.path.realpath(os.path.normpath(os.getcwd()))
-try:
-    prop.hpssd_port = int(sys_cfg.hpssd.port)
-except ValueError:
-    prop.hpssd_port = 2207
-    
-prop.hpssd_host = 'localhost'
-
 prop.username = pwd.getpwuid(os.getuid())[0]
 pdb = pwd.getpwnam(prop.username)
 prop.userhome = pdb[5]
@@ -227,55 +221,55 @@ ERROR_STRINGS = {
                 ERROR_DEVICE_NOT_FOUND : 'Device not found',
                 ERROR_INVALID_DEVICE_ID : 'Unknown/invalid device-id field',
                 ERROR_INVALID_DEVICE_URI : 'Unknown/invalid device-uri field',
-                ERROR_INVALID_MSG_TYPE : 'Unknown message type',
-                ERROR_INVALID_DATA_ENCODING : 'Unknown data encoding',
-                ERROR_INVALID_CHAR_ENCODING : 'Unknown character encoding',
+                #ERROR_INVALID_MSG_TYPE : 'Unknown message type',
+                #ERROR_INVALID_DATA_ENCODING : 'Unknown data encoding',
+                #ERROR_INVALID_CHAR_ENCODING : 'Unknown character encoding',
                 ERROR_DATA_LENGTH_EXCEEDS_MAX : 'Data length exceeds maximum',
-                ERROR_DATA_LENGTH_MISMATCH : "Data length doesn't match length field",
-                ERROR_DATA_DIGEST_MISMATCH : "Digest of data doesn't match digest field",
-                ERROR_INVALID_JOB_ID : 'Invalid job-id',
+                #ERROR_DATA_LENGTH_MISMATCH : "Data length doesn't match length field",
+                #ERROR_DATA_DIGEST_MISMATCH : "Digest of data doesn't match digest field",
+                #ERROR_INVALID_JOB_ID : 'Invalid job-id',
                 ERROR_DEVICE_IO_ERROR : 'Device I/O error',
-                ERROR_STRING_QUERY_FAILED : 'String/error query failed',
-                ERROR_QUERY_FAILED : 'Query failed',
-                ERROR_GUI_NOT_AVAILABLE : 'hpguid not running',
-                ERROR_NO_CUPS_DEVICES_FOUND : 'No CUPS devices found (deprecated)',
+                #ERROR_STRING_QUERY_FAILED : 'String/error query failed',
+                #ERROR_QUERY_FAILED : 'Query failed',
+                #ERROR_GUI_NOT_AVAILABLE : 'hpguid not running',
+                #ERROR_NO_CUPS_DEVICES_FOUND : 'No CUPS devices found (deprecated)',
                 ERROR_NO_PROBED_DEVICES_FOUND : 'No probed devices found',
-                ERROR_INVALID_BUS_TYPE : 'Invalid bus type',
-                ERROR_BUS_TYPE_CANNOT_BE_PROBED : 'Bus cannot be probed',
+                #ERROR_INVALID_BUS_TYPE : 'Invalid bus type',
+                #ERROR_BUS_TYPE_CANNOT_BE_PROBED : 'Bus cannot be probed',
                 ERROR_DEVICE_BUSY : 'Device busy',
-                ERROR_NO_DATA_AVAILABLE : 'No data avaiable',
-                ERROR_INVALID_DEVICEID : 'Invalid/missing DeviceID',
-                ERROR_INVALID_CUPS_VERSION : 'Invlaid CUPS version',
-                ERROR_CUPS_NOT_RUNNING : 'CUPS not running',
+                #ERROR_NO_DATA_AVAILABLE : 'No data avaiable',
+                #ERROR_INVALID_DEVICEID : 'Invalid/missing DeviceID',
+                #ERROR_INVALID_CUPS_VERSION : 'Invlaid CUPS version',
+                #ERROR_CUPS_NOT_RUNNING : 'CUPS not running',
                 ERROR_DEVICE_STATUS_NOT_AVAILABLE : 'DeviceStatus not available',
-                ERROR_DATA_IN_SHORT_READ: 'ChannelDataIn short read',
+                #ERROR_DATA_IN_SHORT_READ: 'ChannelDataIn short read',
                 ERROR_INVALID_SERVICE_NAME : 'Invalid service name',
-                ERROR_INVALID_USER_ERROR_CODE : 'Invalid user level error code',
-                ERROR_ERROR_INVALID_CHANNEL_ID : 'Invalid channel-id',
-                ERROR_CHANNEL_BUSY : 'Channel busy/in-use',
-                ERROR_CHANNEL_CLOSE_FAILED : 'ChannelClose failed. Channel not open',
-                ERROR_UNSUPPORTED_BUS_TYPE : 'Unsupported bus type',
+                #ERROR_INVALID_USER_ERROR_CODE : 'Invalid user level error code',
+                ERROR_ERROR_INVALID_CHANNEL_ID : 'Invalid channel-id (service name)',
+                ERROR_CHANNEL_BUSY : 'Channel busy',
+                #ERROR_CHANNEL_CLOSE_FAILED : 'ChannelClose failed. Channel not open',
+                #ERROR_UNSUPPORTED_BUS_TYPE : 'Unsupported bus type',
                 ERROR_DEVICE_DOES_NOT_SUPPORT_OPERATION : 'Device does not support operation',
-                ERROR_DEVICE_NOT_OPEN : 'Device not open',
-                ERROR_UNABLE_TO_CONTACT_SERVICE : 'Unable to contact service',
-                ERROR_UNABLE_TO_BIND_SOCKET : 'Unable to bind to socket',
+                #ERROR_DEVICE_NOT_OPEN : 'Device not open',
+                #ERROR_UNABLE_TO_CONTACT_SERVICE : 'Unable to contact service',
+                #ERROR_UNABLE_TO_BIND_SOCKET : 'Unable to bind to socket',
                 ERROR_DEVICEOPEN_FAILED : 'Device open failed',
                 ERROR_INVALID_DEVNODE : 'Invalid device node',
-                ERROR_TEST_EMAIL_FAILED : "Email test failed",
+                #ERROR_TEST_EMAIL_FAILED : "Email test failed",
                 ERROR_INVALID_HOSTNAME : "Invalid hostname ip address",
                 ERROR_INVALID_PORT_NUMBER : "Invalid JetDirect port number",
-                ERROR_INTERFACE_BUSY : "Interface busy",
+                #ERROR_INTERFACE_BUSY : "Interface busy",
                 ERROR_NO_CUPS_QUEUE_FOUND_FOR_DEVICE : "No CUPS queue found for device.",
-                ERROR_UNSUPPORTED_MODEL : "Unsupported printer model.",
-                ERROR_INVALID_GUI_NAME: "Invalid GUI",
+                #ERROR_UNSUPPORTED_MODEL : "Unsupported printer model.",
+                #ERROR_INVALID_GUI_NAME: "Invalid GUI",
                 ERROR_DATFILE_ERROR: "DAT file error",
                 ERROR_INVALID_TIMEOUT: "Invalid timeout",
                 ERROR_IO_TIMEOUT: "I/O timeout",
                 ERROR_FAX_INCOMPATIBLE_OPTIONS: "Incompatible fax options",
                 ERROR_FAX_INVALID_FAX_FILE: "Invalid fax file",
-                ERROR_FAX_MUST_RUN_SENDFAX_FIRST: "Run sendfax first",
-                ERROR_FAX_PROCESSING: "Fax processing",
-                ERROR_FAX_READY: "Fax ready",
+                #ERROR_FAX_MUST_RUN_SENDFAX_FIRST: "Run sendfax first",
+                #ERROR_FAX_PROCESSING: "Fax processing",
+                #ERROR_FAX_READY: "Fax ready",
                 ERROR_FAX_FILE_NOT_FOUND: "Fax file not found",
                 ERROR_INTERNAL : 'Unknown internal error',
                }
