@@ -26,6 +26,8 @@ import os.path
 import re
 import glob
 
+pat_prod_num = re.compile("""(\d+)""", re.I)
+
 TYPE_UNKNOWN = 0
 TYPE_STRING = 1
 TYPE_STR = 1
@@ -35,6 +37,156 @@ TYPE_INT = 4
 TYPE_HEX = 5
 TYPE_BITFIELD = 6
 
+TECH_CLASSES = [
+    "Undefined",
+    "Postscript",
+    "DJGenericVIP",
+    #"PSB9100", not used on HPLIP
+    "LJMono",
+    "LJColor",
+    "LJFastRaster",
+    "LJJetReady",
+    "DJ350",
+    #"DJ400", not used on HPLIP
+    "DJ540",
+    "DJ600",
+    "DJ6xx",
+    "DJ6xxPhoto",
+    "DJ630",
+    #"DJ660", not used in HPLIP
+    "DJ8xx",
+    "DJ8x5",
+    "DJ850",
+    "DJ890",
+    "DJ9xx",
+    "DJ9xxVIP",
+    "DJ3600",
+    "DJ3320",
+    "DJ4100",
+    "AP2xxx",
+    "AP21xx",
+    "AP2560",
+    "PSP100",
+    "PSP470",
+    "LJZjsMono",
+    "LJZjsColor",
+    "LJm1005",
+    "QuickConnect",
+    "DJ55xx",
+    "OJProKx50",
+]
+
+TECH_CLASSES.sort()
+
+TECH_CLASS_PDLS = {
+    #"Undefined"    : '?',
+    "Postscript"   : 'ps',
+    "DJGenericVIP" : 'pcl3',
+    #"PSB9100"      : 'pcl3',
+    "LJMono"       : 'pcl3',
+    "LJColor"      : 'pcl3',
+    "LJFastRaster" : 'pclxl',
+    "LJJetReady"   : 'pclxl',
+    "DJ350"        : 'pcl3', 
+    #"DJ400"        : 'pcl3',
+    "DJ540"        : 'pcl3',
+    "DJ600"        : 'pcl3',
+    "DJ6xx"        : 'pcl3',
+    "DJ6xxPhoto"   : 'pcl3',
+    "DJ630"        : 'pcl3',
+    #"DJ660"        : 'pcl3',
+    "DJ8xx"        : 'pcl3',
+    "DJ8x5"        : 'pcl3',
+    "DJ850"        : 'pcl3',
+    "DJ890"        : 'pcl3',
+    "DJ9xx"        : 'pcl3',
+    "DJ9xxVIP"     : 'pcl3',
+    "DJ3600"       : 'lidil',
+    "DJ3320"       : 'lidil',
+    "DJ4100"       : 'lidil',
+    "AP2xxx"       : 'pcl3',
+    "AP21xx"       : 'pcl3',
+    "AP2560"       : 'pcl3',
+    "PSP100"       : 'pcl3',
+    "PSP470"       : 'pcl3',
+    "LJZjsMono"    : 'zjs',
+    "LJZjsColor"   : 'zjs',
+    "LJm1005"      : 'zxstream',
+    "QuickConnect" : 'jpeg',
+    "DJ55xx"       : 'pcl3',
+    "OJProKx50"    : 'pcl3',
+}
+
+
+TECH_SUBCLASSES = [
+    "LargeFormatSuperB",
+    "LargeFormatA3",
+    "CoverMedia", # 3425
+    "FullBleed",
+    "Duplex",
+    "Normal",
+    "Apollo2000",
+    "Apollo2200",
+    "Apollo2500",
+    "NoPhotoMode",
+    "NoPhotoBestHiresModes",
+    "No1200dpiNoSensor",
+    "NoFullBleed",
+    "4x6FullBleed",
+    "300dpiOnly",  # LaserJet 4L
+    "GrayscaleOnly", # DJ540
+]
+
+TECH_SUBCLASSES.sort()
+
+
+# Items will be capitalized unless in this dict
+MODEL_UI_REPLACEMENTS = {'laserjet'   : 'LaserJet',
+                          'psc'        : 'PSC',
+                          'officejet'  : 'Officejet',
+                          'deskjet'    : 'Deskjet',
+                          'hp'         : 'HP',
+                          'business'   : 'Business',
+                          'inkjet'     : 'Inkjet',
+                          'photosmart' : 'Photosmart',
+                          'color'      : 'Color',
+                          'series'     : 'series',
+                          'printer'    : 'Printer',
+                          'mfp'        : 'MFP',
+                          'mopier'     : 'Mopier',
+                          'pro'        : 'Pro',
+                          'apollo'     : 'Apollo',
+                        }
+        
+        
+def normalizeModelUIName(model):
+    ml = model.lower().strip()
+    
+    if 'apollo' in ml:
+        z = ml.replace('_', ' ')
+    else:
+        if ml.startswith("hp"):
+            z = ml[3:].replace('_', ' ')
+        else:
+            z = ml.replace('_', ' ')
+    
+    y = []
+    for x in z.split():
+        if pat_prod_num.search(x): # don't cap items like cp1700dn
+            y.append(x)
+        else:
+            y.append(MODEL_UI_REPLACEMENTS.get(x, x.capitalize()))
+
+    if 'apollo' in ml:
+        return ' '.join(y)
+    else:
+        return "HP " + ' '.join(y)
+        
+
+def normalizeModelName(model):
+    return utils.xstrip(model.replace(' ', '_').replace('__', '_').replace('~','').replace('/', '_'), '_')
+        
+
 class ModelData:
     def __init__(self, root_path=None):
         if root_path is None:
@@ -65,7 +217,6 @@ class ModelData:
             'panel-check-type' : TYPE_INT,
             'pcard-type' : TYPE_INT,
             'plugin' : TYPE_INT,
-            'plugin-library' : TYPE_STR,
             'power-settings': TYPE_INT,
             'pq-diag-type' : TYPE_INT,
             'r-type' : TYPE_INT,
@@ -77,10 +228,12 @@ class ModelData:
             'support-released' : TYPE_BOOL,
             'support-type' : TYPE_INT,
             'support-ver' : TYPE_STR,
-            'tech-class' : TYPE_STR,
+            'tech-class' : TYPE_LIST,
+            'tech-subclass' : TYPE_LIST,
             'tech-type' : TYPE_INT,
             'usb-pid' : TYPE_HEX,
             'usb-vid' : TYPE_HEX,
+            'job-storage' : TYPE_INT,
             }
             
         self.RE_FIELD_TYPES = {
@@ -202,6 +355,9 @@ class ModelData:
                         #value = utils.to_bool(value)
                         value = int(value)
                         
+                    elif typ == TYPE_LIST:
+                        value = [x for x in value.split(',') if x]
+                        
                     cache[read_section][key] = value
 
         fd.close()
