@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@ import re
 import getopt
 import time
 import operator
+import os
 
 # Local
 from base.g import *
@@ -122,137 +123,154 @@ def usage(typ='text'):
 log.set_module("hp-clean")
 
 try:
-    opts, args = getopt.getopt(sys.argv[1:], 'p:d:hl:b:g',
-                                ['printer=', 'device=', 'help', 'help-rest', 'help-man', 
-                                 'logging=', 'bus=', 'help-desc'])
-except getopt.GetoptError, e:
-    log.error(e.msg)
-    usage()
 
-bus = device.DEFAULT_PROBE_BUS
-log_level = logger.DEFAULT_LOG_LEVEL
-printer_name = None
-device_uri = None
-
-if os.getenv("HPLIP_DEBUG"):
-    log.set_level('debug')
-
-for o, a in opts:
-    if o in ('-h', '--help'):
+    try:
+        opts, args = getopt.getopt(sys.argv[1:], 'p:d:hl:b:g',
+                                    ['printer=', 'device=', 'help', 'help-rest', 'help-man', 
+                                     'logging=', 'bus=', 'help-desc'])
+    except getopt.GetoptError, e:
+        log.error(e.msg)
         usage()
 
-    elif o == '--help-rest':
-        usage('rest')
+    bus = device.DEFAULT_PROBE_BUS
+    log_level = logger.DEFAULT_LOG_LEVEL
+    printer_name = None
+    device_uri = None
 
-    elif o == '--help-man':
-        usage('man')
-
-    elif o == '--help-desc':
-        print __doc__,
-        sys.exit(0)
-
-    elif o in ('-p', '--printer'):
-        if a.startswith('*'):
-            printer_name = cups.getDefaultPrinter()
-        else:
-            printer_name = a
-
-    elif o in ('-d', '--device'):
-        device_uri = a
-
-    elif o in ('-b', '--bus'):
-        bus = a.lower().strip()
-
-    elif o in ('-l', '--logging'):
-        log_level = a.lower().strip()
-        if not log.set_level(log_level):
-            usage()
-
-    elif o == '-g':
+    if os.getenv("HPLIP_DEBUG"):
         log.set_level('debug')
 
+    for o, a in opts:
+        if o in ('-h', '--help'):
+            usage()
 
-if not device.validateBusList(bus):
-    usage()
+        elif o == '--help-rest':
+            usage('rest')
 
-if device_uri and printer_name:
-    log.error("You may not specify both a printer (-p) and a device (-d).")
-    usage()
+        elif o == '--help-man':
+            usage('man')
 
-utils.log_title(__title__, __version__)
-
-if not device_uri and not printer_name:
-    try:
-        device_uri = device.getInteractiveDeviceURI(bus, filter={'clean-type': (operator.gt, 0)})
-        if device_uri is None:
+        elif o == '--help-desc':
+            print __doc__,
             sys.exit(0)
-    except Error:
-        log.error("Error occured during interactive mode. Exiting.")
+
+        elif o in ('-p', '--printer'):
+            if a.startswith('*'):
+                printer_name = cups.getDefaultPrinter()
+                log.debug(printer_name)
+                
+                if printer_name is not None:
+                    log.info("Using CUPS default printer: %s" % printer_name)
+                else:
+                    log.error("CUPS default printer is not set.")
+                
+            else:
+                printer_name = a
+
+        elif o in ('-d', '--device'):
+            device_uri = a
+
+        elif o in ('-b', '--bus'):
+            bus = [x.lower().strip() for x in a.split(',')]
+            if not device.validateBusList(bus):
+                usage()
+
+        elif o in ('-l', '--logging'):
+            log_level = a.lower().strip()
+            if not log.set_level(log_level):
+                usage()
+
+        elif o == '-g':
+            log.set_level('debug')
+
+
+    if os.getuid() == 0:
+        log.warn("hp-clean should not be run as root.")
+    
+    if not device.validateBusList(bus):
+        usage()
+
+    if device_uri and printer_name:
+        log.error("You may not specify both a printer (-p) and a device (-d).")
+        usage()
+
+    utils.log_title(__title__, __version__)
+
+    if not device_uri and not printer_name:
+        try:
+            device_uri = device.getInteractiveDeviceURI(bus, filter={'clean-type': (operator.gt, 0)})
+            if device_uri is None:
+                sys.exit(0)
+        except Error:
+            log.error("Error occured during interactive mode. Exiting.")
+            sys.exit(0)
+
+    try:
+        d = device.Device(device_uri, printer_name)
+    except Error, e:
+        log.error("Unable to open device: %s" % e.msg)
         sys.exit(0)
 
-try:
-    d = device.Device(device_uri, printer_name)
-except Error, e:
-    log.error("Unable to open device: %s" % e.msg)
-    sys.exit(0)
+    if d.device_uri is None and printer_name:
+        log.error("Printer '%s' not found." % printer_name)
+        sys.exit(0)
 
-if d.device_uri is None and printer_name:
-    log.error("Printer '%s' not found." % printer_name)
-    sys.exit(0)
+    if d.device_uri is None and device_uri:
+        log.error("Malformed/invalid device-uri: %s" % device_uri)
+        sys.exit(0)
 
-if d.device_uri is None and device_uri:
-    log.error("Malformed/invalid device-uri: %s" % device_uri)
-    sys.exit(0)
+    user_cfg.last_used.device_uri = d.device_uri
 
-user_cfg.last_used.device_uri = d.device_uri
-
-if not d.cups_printers:
-    log.error("No appropriate printer queue found for device. Please setup printer with hp-setup and try again.")
-    sys.exit(1)
-
-try:
-    try:
-        d.open()
-    except Error:
-        log.error("Unable to print to printer. Please check device and try again.")
+    if not d.cups_printers:
+        log.error("No appropriate printer queue found for device. Please setup printer with hp-setup and try again.")
         sys.exit(1)
 
-    if d.isIdleAndNoError():
-        clean_type = d.mq.get('clean-type', 0)
-        log.debug("Clean type=%d" % clean_type)
+    try:
+        try:
+            d.open()
+        except Error:
+            log.error("Unable to print to printer. Please check device and try again.")
+            sys.exit(1)
+
+        if d.isIdleAndNoError():
+            clean_type = d.mq.get('clean-type', 0)
+            log.debug("Clean type=%d" % clean_type)
+            d.close()
+
+            try:
+                if clean_type == CLEAN_TYPE_PCL:
+                    maint.cleaning(d, clean_type, maint.cleanType1, maint.primeType1,
+                                    maint.wipeAndSpitType1, tui.load_paper_prompt,
+                                    CleanUI1, CleanUI2, CleanUI3,
+                                    None)
+        
+                elif clean_type == CLEAN_TYPE_LIDIL:
+                    maint.cleaning(d, clean_type, maint.cleanType2, maint.primeType2,
+                                    maint.wipeAndSpitType2, tui.load_paper_prompt,
+                                    CleanUI1, CleanUI2, CleanUI3,
+                                    None)
+        
+                elif clean_type == CLEAN_TYPE_PCL_WITH_PRINTOUT:
+                    maint.cleaning(d, clean_type, maint.cleanType1, maint.primeType1,
+                                    maint.wipeAndSpitType1, tui.load_paper_prompt,
+                                    CleanUI1, CleanUI2, CleanUI3,
+                                    None)
+            
+                else:
+                    log.error("Cleaning not needed or supported on this device.")
+            
+            except Error, e:
+                log.error("An error occured: %s" % e[0])
+
+        else:
+            log.error("Device is busy or in an error state. Please check device and try again.")
+            sys.exit(1)
+    finally:
         d.close()
 
-        try:
-            if clean_type == CLEAN_TYPE_PCL:
-                maint.cleaning(d, clean_type, maint.cleanType1, maint.primeType1,
-                                maint.wipeAndSpitType1, tui.load_paper_prompt,
-                                CleanUI1, CleanUI2, CleanUI3,
-                                None)
+except KeyboardInterrupt:
+    log.error("User exit")
     
-            elif clean_type == CLEAN_TYPE_LIDIL:
-                maint.cleaning(d, clean_type, maint.cleanType2, maint.primeType2,
-                                maint.wipeAndSpitType2, tui.load_paper_prompt,
-                                CleanUI1, CleanUI2, CleanUI3,
-                                None)
-    
-            elif clean_type == CLEAN_TYPE_PCL_WITH_PRINTOUT:
-                maint.cleaning(d, clean_type, maint.cleanType1, maint.primeType1,
-                                maint.wipeAndSpitType1, tui.load_paper_prompt,
-                                CleanUI1, CleanUI2, CleanUI3,
-                                None)
-        
-            else:
-                log.error("Cleaning not needed or supported on this device.")
-        
-        except Error, e:
-            log.error("An error occured: %s" % e[0])
-
-    else:
-        log.error("Device is busy or in an error state. Please check device and try again.")
-        sys.exit(1)
-finally:
-    d.close()
-
 log.info("")
 log.info("Done.")
 
