@@ -20,15 +20,16 @@
 # Author: Don Welch
 #
 
-# Local
-from base.g import *
-from base import utils, tui
-from core_install import *
-
 # Std Lib
 import os
 import sys
 import getpass
+import signal
+
+# Local
+from base.g import *
+from base import utils, tui
+from core_install import *
 
 
 def progress_callback(cmd="", desc="Working..."):
@@ -45,21 +46,21 @@ def option_question_callback(opt, desc):
     if not ok: sys.exit(0)
     return ans
 
-def start(language, auto=True, test_depends=False, test_unknown=False):
+def start(language, auto=True, test_depends=False, test_unknown=False, assume_network=False, max_retries=3):
     try:
         core =  CoreInstall(MODE_INSTALLER, INTERACTIVE_MODE)
-    
+
         if core.running_as_root():
             log.error("You are running the installer as root. It is highly recommended that you run the installer as")
             log.error("a regular (non-root) user. Do you still wish to continue?")
-    
+
             ok, ans = tui.enter_yes_no(log.bold("Continue with installation"), 'n')
             if not ans or not ok:
                 sys.exit(1)
-    
+
         if auto:
             log.note("Running in automatic mode. The most common options will be selected.")
-    
+
         log.info("")
         log.note("Defaults for each question are maked with a '*'. Press <enter> to accept the default.")
 
@@ -67,19 +68,20 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
             tui.title("INSTALLATION MODE")
             log.info("Automatic mode will install the full HPLIP solution with the most common options.")
             log.info("Custom mode allows you to chose installation options to fit specific requirements.")
-            
-            if os.getenv('DISPLAY') and utils.find_browser() is not None:
+
+            #if os.getenv('DISPLAY') and utils.find_browser() is not None:
+            if 0:
                 ok, choice = tui.enter_choice("\nPlease choose the installation mode (a=automatic*, c=custom, w=web installer, q=quit) : ", 
                     ['a', 'c', 'w'], 'a')
             else:
                 ok, choice = tui.enter_choice("\nPlease choose the installation mode (a=automatic*, c=custom, q=quit) : ", 
                     ['a', 'c'], 'a')
-                    
+
             if not ok: sys.exit(0)
-            
+
             if choice == 'a':
                 auto = True
-                
+
             elif choice == 'w':
                 import web_install
                 log.debug("Starting web browser installer...")
@@ -88,28 +90,28 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
         log.info("\nInitializing. Please wait...")
         core.init()
-        
+
         if test_unknown:
             core.distro_name = 'unknown'
             core.distro = 0
             core.distro_version = 0
-        
-        
+
+
         #
         # HPLIP vs. HPIJS INSTALLATION
         #
-        
+
         if not auto:
             tui.title("INSTALL TYPE")
             log.info("For most users, it is recommended to install HPLIP with full support (scanning, faxing, toolbox, etc).")
             log.info("For servers or minimal installations, you can also install print support only (using HPIJS).")
-            
+
             ok, choice = tui.enter_choice("\nInstall full support (recommended) or print-only support (m=multifunction*, s=single func, q=quit) ?", 
                 ['m', 's'], 'm')
             if not ok: sys.exit(0)
             if choice  == 's':
                 core.selected_component = 'hpijs'
-                
+
         log.debug(core.selected_component)
 
         #
@@ -124,27 +126,27 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
         else:
             log.info("This installer will install HPIJS version %s on your computer." % core.version_public)
             core.hpijs_build = True
-            
+
         log.info("Please close any running package management systems now (YaST, Adept, Synaptic, Up2date, etc).")
 
-        #
-        # RELEASE NOTES
-        #
-
-        if not auto: 
-            if os.getenv('DISPLAY'):
-                tui.title("VIEW RELEASE NOTES")
-                log.info("Release notes from this version are available as a web (HTML) document.")
-                log.info("The release notes file will be shown in a separate web browser window.")
-
-                ok, ans = tui.enter_yes_no("\nWould you like to view the release notes for this version of HPLIP", 'n')
-                
-                if ok and ans:
-                    log.info("Displaying release notes in a browser window...")
-                    core.show_release_notes_in_browser()
-                
-                if not ok:
-                    sys.exit(0)
+##        #
+##        # RELEASE NOTES
+##        #
+##
+##        if not auto: 
+##            if os.getenv('DISPLAY'):
+##                tui.title("VIEW RELEASE NOTES")
+##                log.info("Release notes from this version are available as a web (HTML) document.")
+##                log.info("The release notes file will be shown in a separate web browser window.")
+##
+##                ok, ans = tui.enter_yes_no("\nWould you like to view the release notes for this version of HPLIP", 'n')
+##
+##                if ok and ans:
+##                    log.info("Displaying release notes in a browser window...")
+##                    core.show_release_notes_in_browser()
+##
+##                if not ok:
+##                    sys.exit(0)
 
         # For testing, mark all dependencies missing
         if test_depends:
@@ -154,19 +156,6 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
         num_req_missing = core.count_num_required_missing_dependencies()
         num_opt_missing = core.count_num_optional_missing_dependencies()
 
-        #
-        # SELECT OPTIONS TO INSTALL
-        #
-
-        if not auto:
-            tui.title("SELECT HPLIP OPTIONS")
-            log.info("You can select which HPLIP options to enable. Some options require extra dependencies.")
-            log.info("")
-            num_opt_missing = core.select_options(option_question_callback)
-
-
-        log.debug("Req missing=%d Opt missing=%d HPOJ=%s HPLIP=%s Component=%s" % \
-            (num_req_missing, num_opt_missing, core.hpoj_present, core.hplip_present, core.selected_component))
 
         #
         # CONFIRM AND SELECT DISTRO NAME AND VERSION
@@ -186,10 +175,10 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
         if core.distro_known():
             ok, distro_ok = tui.enter_yes_no('Is "%s %s" your correct distro/OS and version'
                 % (core.get_distro_data('display_name', '(unknown)'), core.distro_version))
-        
+
         if not ok:
             sys.exit(0)
-            
+
         if not distro_ok:
             tui.title("DISTRO/OS SELECTION")
             core.distro, core.distro_version = DISTRO_UNKNOWN, DISTRO_VER_UNKNOWN
@@ -224,7 +213,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
             ok, y = tui.enter_range("\nEnter number 0...%d (q=quit) ?" % (x-1), 0, x-1)
             if not ok: sys.exit(0)
-            
+
             core.distro = d_temp[y]
             core.distro_name = core.distros_index[core.distro]
             distro_display_name = core.distros[core.distro_name]['display_name']
@@ -274,7 +263,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                 ok, core.distro_version_int = tui.enter_range("\nEnter number 0...%d (q=quit) ?" % 
                     (x-1), 0, x-1)
                 if not ok: sys.exit(0)
-                
+
                 if core.distro_version_int == 0:
                     core.distro_version = DISTRO_VER_UNKNOWN
                     core.distro_version_supported = False
@@ -287,7 +276,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                     core.distro_version, core.distro_version_supported))
 
                 core.distro_changed()
-                
+
                 log.info("\nDistro set to: %s %s" % 
                     (core.get_distro_data('display_name', '(unknown)'), core.distro_version))
 
@@ -313,9 +302,34 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                         log.warning("Missing OPTIONAL dependency: %s (%s) [Optional for option '%s']" % (d, desc, opt))
 
                 ok, ans = tui.enter_yes_no("\n\nDo you still wish to continue")
-                    
+
                 if not ok or not ans: sys.exit(0)
 
+        #
+        # SELECT OPTIONS TO INSTALL
+        #
+
+        tui.title("SELECT HPLIP OPTIONS")
+
+        if not auto:
+            log.info("You can select which HPLIP options to enable. Some options require extra dependencies.")
+            log.info("")
+            num_opt_missing = core.select_options(option_question_callback)
+
+        else: # auto
+            ok, enable_par = tui.enter_yes_no("Would you like to enable support for parallel (LPT:) connected printers?", 'n')
+            if not ok: sys.exit(0)
+
+            core.selected_options['parallel'] = enable_par
+
+            if enable_par:
+                log.info("Parallel support enabled.")
+
+
+        log.debug("Req missing=%d Opt missing=%d HPOJ=%s HPLIP=%s Component=%s" % \
+            (num_req_missing, num_opt_missing, core.hpoj_present, core.hplip_present, core.selected_component))
+
+
         #
         # COLLECT SUPERUSER PASSWORD
         #
@@ -344,7 +358,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
                 if ver_notes:
                     log.info(ver_notes)
-                    
+
                 log.info("")
 
                 if not tui.continue_prompt("Please read the installation notes."):
@@ -357,7 +371,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
         if core.run_pre_install(progress_callback): # some cmds were run...
             num_req_missing = core.count_num_required_missing_dependencies()
             num_opt_missing = core.count_num_optional_missing_dependencies()  
-        
+
         #
         # REQUIRED DEPENDENCIES INSTALL
         #
@@ -383,14 +397,14 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                     else:
                         ok, answer = tui.enter_yes_no("\nWould you like to have this installer install the missing dependency")
                         if not ok: sys.exit(0)
-                        
+
                     if answer:
                         ok = True
                         log.debug("Adding '%s' to list of dependencies to install." % depend)
                         depends_to_install.append(depend)
 
                 else:
-                    log.error("This installer cannot install this dependency for your distro/OS and/or version.")
+                    log.warn("This installer cannot install '%s' for your distro/OS and/or version." % depend)
 
                 if not ok:
                     log.error("Installation cannot continue without this dependency. Please manually install this dependency and re-run this installer.")                    
@@ -410,7 +424,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
             log.notice("Installation of dependencies requires an active internet connection.")
 
             for depend, desc, required_for_opt, opt in core.missing_optional_dependencies():
-                
+
                 if required_for_opt:
                     log.warning("Missing REQUIRED dependency for option '%s': %s (%s)" % (opt, depend, desc))
 
@@ -429,7 +443,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                     else:
                         ok, answer = tui.enter_yes_no("\nWould you like to have this installer install the missing dependency")
                         if not ok: sys.exit(0)
-                        
+
                     if answer:
                         log.debug("Adding '%s' to list of dependencies to install." % depend)
                         depends_to_install.append(depend)
@@ -442,7 +456,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                             log.warn("Option '%s' has been turned off." % opt)
                             core.selected_options[opt] = False
                 else:
-                    log.error("This installer cannot install this dependency for your distro/OS and/or version.")
+                    log.warn("This installer cannot install '%s' for your distro/OS and/or version." % depend)
 
                     if required_for_opt:
                         log.warn("Option '%s' has been turned off." % opt)
@@ -463,32 +477,45 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
             # CHECK FOR RUNNING PACKAGE MANAGER
             #
 
-            p = core.check_pkg_mgr()
-            while p:
-                ok, user_input = tui.enter_choice("A package manager '%s' appears to be running. Please quit the package manager and press enter to continue (i=ignore, q=quit*) :" 
-                    % p, ['i', 'q'], 'q')
-                
+            pid, cmdline = core.check_pkg_mgr()
+            while pid:
+                ok, user_input = tui.enter_choice("A package manager '%s' appears to be running. Please quit the package manager and press enter to continue (i=ignore, r=retry*, f=force, q=quit) :" 
+                    % cmdline, ['i', 'r', 'q', 'f'], 'r')
+
                 if not ok: sys.exit(0)
-                
+
                 if user_input == 'i':
                     log.warn("Ignoring running package manager. Some package operations may fail.")
                     break
 
-                p = core.check_pkg_mgr()
+                if user_input == 'f':
+                    ok, ans = tui.enter_yes_no("\nForce quit of package manager '%s'" % cmdline, 'y')
+
+                    if not ok: sys.exit(0)
+
+                    if ans:
+                        cmd = core.su_sudo() % ("kill %d" % pid)
+                        status, output = core.run(cmd)
+
+                        if status != 0:
+                            log.error("Failed to kill process. You may need to manually quit the program.")
+
+                pid, cmdline = core.check_pkg_mgr()
 
 
             #
             # CHECK FOR ACTIVE NETWORK CONNECTION
             #
 
-            tui.title("CHECKING FOR NETWORK CONNECTION")
+            if not assume_network:
+                tui.title("CHECKING FOR NETWORK CONNECTION")
 
-            if not core.check_network_connection():
-                log.error("\nThe network appears to be unreachable. Installation cannot complete without access to")
-                log.error("distribution repositories. Please check the network and try again.")
-                sys.exit(1)
-            else:
-                log.info("Network connection present.")
+                if not core.check_network_connection():
+                    log.error("\nThe network appears to be unreachable. Installation cannot complete without access to")
+                    log.error("distribution repositories. Please check the network and try again.")
+                    sys.exit(1)
+                else:
+                    log.info("Network connection present.")
 
             #
             # PRE-DEPEND
@@ -503,21 +530,27 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
             tui.title("DEPENDENCY AND CONFLICT RESOLUTION")
 
-            packages_to_install = []
+            packages = []
             commands_to_run = []
             package_mgr_cmd = core.get_distro_data('package_mgr_cmd')
+
+            # HACK!
+            individual_pkgs = True
+            if package_mgr_cmd.startswith('xterm'):
+                individual_pkgs = False
+
             if package_mgr_cmd:
                 log.debug("Preparing to install packages and run commands...")
 
                 for d in depends_to_install:
                     log.debug("*** Processing dependency: %s" % d)
-                    packages, commands = core.get_dependency_data(d)
+                    pkgs, commands = core.get_dependency_data(d)
 
-                    if packages:
+                    if pkgs:
                         log.debug("Package(s) '%s' will be installed to satisfy dependency '%s'." % 
-                            (','.join(packages), d))
+                            (','.join(pkgs), d))
 
-                        packages_to_install.extend(packages)
+                        packages.extend(pkgs)
 
                     if commands:
                         log.debug("Command(s) '%s' will be run to satisfy dependency '%s'." % 
@@ -525,34 +558,68 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
                         commands_to_run.extend(commands)
 
-                packages_to_install = ' '.join(packages_to_install)
-
             else:
                 log.error("Invalid package manager")
 
-            if package_mgr_cmd and packages_to_install:
-                while True:
-                    cmd = utils.cat(package_mgr_cmd)
-                    log.debug("Package manager command: %s" % cmd)
+            log.debug("Packages: %s" % packages)
+            log.debug("Commands: %s" % commands_to_run)
+            log.debug("Install individual packages: %s" % individual_pkgs)
 
-                    log.info("Running '%s'\nPlease wait, this may take several minutes..." % cmd)
-                    status, output = core.run(cmd)
+            if package_mgr_cmd and packages:
+                if individual_pkgs:
+                    for packages_to_install in packages:
+                        retries = 0
+                        while True:
+                            cmd = utils.cat(package_mgr_cmd)
+                            log.debug("Package manager command: %s" % cmd)
 
-                    if status != 0:
-                        log.error("Package install command failed with error code %d" % status)
-                        ok, ans = tui.enter_yes_no("Would you like to retry installing the missing package(s)")
-                        
-                        if not ok: sys.exit(0)
-                        
-                        if ans:
-                            continue
+                            log.info("Running '%s'\nPlease wait, this may take several minutes..." % cmd)
+                            status, output = core.run(cmd)
+
+                            if status != 0:
+                                retries += 1
+                                if retries < (max_retries+1):
+                                    log.error("Command failed. Re-try #%d..." % retries)
+                                    continue
+
+                                log.error("Package install command failed with error code %d" % status)
+                                ok, ans = tui.enter_yes_no("Would you like to retry installing the missing package(s)")
+
+                                if not ok: 
+                                    sys.exit(0)
+
+                                if ans:
+                                    continue
+                                else:
+                                    log.warn("Some HPLIP functionality might not function due to missing package(s).")
+                                    break
+                            else:
+                                break
+
+                else:
+                    packages_to_install = ' '.join(packages)
+                    while True:
+                        cmd = utils.cat(package_mgr_cmd)
+                        log.debug("Package manager command: %s" % cmd)
+
+                        log.info("Running '%s'\nPlease wait, this may take several minutes..." % cmd)
+                        status, output = core.run(cmd)
+
+                        if status != 0:
+                            log.error("Package install command failed with error code %d" % status)
+                            ok, ans = tui.enter_yes_no("Would you like to retry installing the missing package(s)")
+
+                            if not ok: 
+                                sys.exit(0)
+
+                            if ans:
+                                continue
+                            else:
+                                log.warn("Some HPLIP functionality might not function due to missing package(s).")
+                                break
                         else:
-                            log.warn("Some HPLIP functionality might not function due to missing package(s).")
                             break
 
-                    else:
-                        break
-
             if commands_to_run:
                 for cmd in commands_to_run:
                     log.debug(cmd)
@@ -578,9 +645,9 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                         answer = True
                     else:
                         ok, answer = tui.enter_yes_no("\nWould you like to have this installer attempt to uninstall HPOJ")
-                    
+
                     if not ok: sys.exit(0)
-                    
+
                     if answer:
                         failed = core.remove_hpoj(progress_callback)
 
@@ -611,7 +678,7 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                     else:
                         ok, answer = tui.enter_yes_no("\nWould you like to have this installer attempt to uninstall the previously installed HPLIP")
                     if not ok: sys.exit(0)
-                    
+
                     if answer:
                         failed = core.remove_hplip(progress_callback)
 
@@ -628,15 +695,15 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
             #
             # POST-DEPEND
             #
-            
+
             tui.title("RUNNING POST-PACKAGE COMMANDS")
             core.run_post_depend(progress_callback)
-            
-            
+
+
             # 
             # DEPENDENCIES RE-CHECK
             #
-            
+
             tui.title("RE-CHECKING DEPENDENCIES")
             core.check_dependencies()
 
@@ -662,13 +729,11 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
                 else:
                     log.warn("An optional dependency '%s (%s)' is still missing." % (depend, desc))
                     log.warn("Some features may not function as expected.") 
-     
-            
+
+
             if not num_opt_missing and not num_req_missing:
                 log.info("OK")
 
-
-
         #
         # INSTALL LOCATION
         #
@@ -696,7 +761,12 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
             status, output = core.run(cmd)
 
             if status != 0:
-                log.error("'%s' command failed with status code %d" % (cmd, status))
+                if 'configure' in cmd:
+                    log.error("Configure failed with error: %s" % CONFIGURE_ERRORS.get(status, CONFIGURE_ERRORS[1]))
+
+                else:
+                    log.error("'%s' command failed with status code %d" % (cmd, status))
+
                 sys.exit(0)
             else:
                 log.info("Command completed successfully.")
@@ -707,58 +777,59 @@ def start(language, auto=True, test_depends=False, test_unknown=False):
 
         tui.title("POST-BUILD COMMANDS")  
         core.run_post_build(progress_callback)
-        
+
         # Restart or re-plugin if necessary (always True in 2.7.9+)
-        if core.restart_required:
+        if core.restart_required and core.selected_component != 'hpijs':
             tui.title("RESTART OR RE-PLUG IS REQUIRED")
             cmd = core.su_sudo() % "hp-setup"
             paragraph = """If you are installing a USB connected printer, and the printer was plugged in when you started this installer, you will need to either restart your PC or unplug and re-plug in your printer (USB cable only). If you choose to restart, run this command after restarting: %s  (Note: If you are using a parallel connection, you will have to restart your PC. If you are using network/wireless, you can ignore and continue).""" % cmd 
-            
+
             for p in tui.format_paragraph(paragraph):
                 log.info(p)
             log.info("")
-                
+
             ok, choice = tui.enter_choice("Restart or re-plug in your printer (r=restart, p=re-plug in*, i=ignore/continue, q=quit) : ", 
                 ['r', 'p', 'i'], 'p')
-                
+
             if not ok: sys.exit(0)
-            
+
             if choice == 'r':
                 log.note("")
                 log.note("IMPORTANT! Make sure to save all work in all open applications before restarting!")
-            
+
                 ok, ans = tui.enter_yes_no(log.bold("Restart now"), 'n')
                 if not ok: sys.exit(0)
                 if ans:
                     ok = core.restart()
                     if not ok:
                         log.error("Restart failed. Please restart using the system menu.")
-                    
+
                 sys.exit(0)
-                
+
             elif choice == 'p': # 'p'
                 if not tui.continue_prompt("Please unplug and re-plugin your printer now. "):
                     sys.exit(0)
-                    
+
         #
         # SETUP PRINTER
         #
-        tui.title("PRINTER SETUP")
+        if core.selected_component != 'hpijs':
+            tui.title("PRINTER SETUP")
 
-        if auto:
-            install_printer = True
-        else:
-            ok, install_printer = tui.enter_yes_no("Would you like to setup a printer now")
-            if not ok: sys.exit(0)
+            if auto:
+                install_printer = True
+            else:
+                ok, install_printer = tui.enter_yes_no("Would you like to setup a printer now")
+                if not ok: sys.exit(0)
 
-        if install_printer:
-            log.info("Please make sure your printer is connected and powered on at this time.")
-            if not core.run_hp_setup():
-                log.error("hp-setup failed. Please run hp-setup manually.")
+            if install_printer:
+                log.info("Please make sure your printer is connected and powered on at this time.")
+                if not core.run_hp_setup():
+                    log.error("hp-setup failed. Please run hp-setup manually.")
 
     except KeyboardInterrupt:
         log.info("")
         log.error("Aborted.")
 
     sys.exit(0)
-    
+
