@@ -809,7 +809,8 @@ int __attribute__ ((visibility ("hidden"))) power_up(mud_device *pd, int fd)
    }
    else if ((pSf = strstr(pd->id, "VSTATUS:")) != NULL)
    {
-      if ((pSf = strstr(pSf+8, "OFFF")) == NULL)
+      /* DJ895C returns $XB0$XC0 (unknown pens) when powered off. */
+      if (!(strstr(pSf+8, "OFFF") || strstr(pSf+8, "PWDN") || strstr(pSf+8, "$X")))
          return 0;   /* already powered up */
    }
    else
@@ -842,7 +843,7 @@ static int new_channel(mud_device *pd, int index, const char *sn)
       goto bugout; 
    }
 
-   if (index == HPMUD_EWS_CHANNEL || index == HPMUD_SOAPSCAN_CHANNEL || index == HPMUD_SOAPFAX_CHANNEL)
+   if (index == HPMUD_EWS_CHANNEL || index == HPMUD_SOAPSCAN_CHANNEL || index == HPMUD_SOAPFAX_CHANNEL || index == HPMUD_MARVELL_SCAN_CHANNEL)
       pd->channel[index].vf = musb_comp_channel_vf;
    else if (pd->io_mode == HPMUD_RAW_MODE || pd->io_mode == HPMUD_UNI_MODE)
       pd->channel[index].vf = musb_raw_channel_vf;
@@ -1260,10 +1261,9 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) musb_channel_open(mud_
    else
    {
       if ((stat = (pd->channel[index].vf.open)(&pd->channel[index])) != HPMUD_R_OK)  /* call transport specific open */
-      {
          del_channel(pd, &pd->channel[index]);   /* open failed, cleanup */
-      }
-      *cd = index;
+      else
+         *cd = index;
    }
 
    pthread_mutex_unlock(&pd->mutex);
@@ -1407,6 +1407,9 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) musb_comp_channel_open
       case HPMUD_SOAPFAX_CHANNEL:
          fd = FD_ff_3_1;   
          break;
+      case HPMUD_MARVELL_SCAN_CHANNEL:
+         fd = FD_ff_ff_ff;   
+         break;
       default:
          stat = HPMUD_R_INVALID_SN;
          BUG("invalid %s channel=%d\n", pc->sn, pc->index);
