@@ -123,6 +123,8 @@ public:
         "Deskjet 6988\0"
 		"deskjet 9600\0"
 		"Deskjet 9800\0"
+        "Deskjet D25\0"
+        "Deskjet F42\0"
         "Business Inkjet 1000\0"
 		"hp business inkjet 1100\0"
    		"HP Business Inkjet 1200\0"
@@ -166,6 +168,7 @@ public:
         "Officejet J36\0"
         "Officejet J55\0"
         "Officejet J57\0"
+        "Officejet J64\0"
         "Officejet K71\0"
         "Photosmart 2570\0"
 		"Photosmart 2600\0"
@@ -178,10 +181,12 @@ public:
         "Photosmart A320\0"
         "Photosmart A440\0"
         "Photosmart Pro B8300\0"
+        "Photosmart Pro B88\0"
         "Photosmart C31\0"
         "Photosmart C41\0"
         "Photosmart C42\0"
         "Photosmart C43\0"
+        "Photosmart C44\0"
         "Photosmart C51\0"
         "Photosmart C52\0"
         "Photosmart C61\0"
@@ -192,6 +197,7 @@ public:
         "Photosmart D5060\0"
         "Photosmart D51\0"
         "Photosmart D53\0"
+        "Photosmart D54\0"
         "Photosmart D61\0"
         "Photosmart D71\0"
         "Photosmart D72\0"
