@@ -384,6 +384,10 @@ class LJFastRasterProxy;
 class LJZjsMonoProxy;
 #endif
 
+#ifdef APDK_LJM1005
+class LJM1005Proxy;
+#endif
+
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
 class PSP100Proxy;
 class PSP470Proxy;
@@ -469,6 +473,11 @@ class Apollo21xxProxy;
 #ifdef APDK_APOLLO2XXX
 class Apollo2xxxProxy;
 #endif
+
+#ifdef APDK_QUICKCONNECT
+class QuickConnectProxy;
+#endif
+
 //DeviceRegistry
 //! Isolates device dependencies
 /*!
@@ -530,6 +539,10 @@ public:
     static LJZjsMonoProxy s_LJZjsMonoProxy;
 #endif
 
+#ifdef APDK_LJM1005
+    static LJM1005Proxy s_LJM1005Proxy;
+#endif
+
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
     static PSP100Proxy s_PSP100Proxy;
     static PSP470Proxy s_PSP470Proxy;
@@ -616,6 +629,10 @@ public:
     static Apollo2xxxProxy s_Apollo2xxxProxy;
 #endif
 
+#ifdef APDK_QUICKCONNECT
+    static QuickConnectProxy s_QuickConnectProxy;
+#endif
+
 }; //DeviceRegistry
 
 
@@ -1141,6 +1158,24 @@ protected:
     DRIVER_ERROR SendCAPy (unsigned int iAbsY);
 }; // HeaderLJZjs
 
+//ClassName
+/*
+******************************************************************************/
+class HeaderQuickConnect : public Header
+{
+public:
+    HeaderQuickConnect (Printer *p, PrintContext *pc);
+    virtual DRIVER_ERROR Send ();
+    virtual DRIVER_ERROR FormFeed ();
+protected:
+    DRIVER_ERROR EndJob ();
+    DRIVER_ERROR SendCAPy (unsigned int iAbsY);
+}; // HeaderQuickConnect
+
+//ClassName
+/*
+******************************************************************************/
+
 class RasterSender : public Processor
 {
 friend class Header;
