@@ -1,7 +1,7 @@
 /*****************************************************************************\
   ljjetready.cpp : Implimentation for the LJJetReady class
 
-  Copyright (c) 1996 - 2006, Hewlett-Packard Co.
+  Copyright (c) 1996 - 2008, Hewlett-Packard Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -646,7 +646,7 @@ DRIVER_ERROR LJJetReady::Encapsulate (const RASTERDATA* InputRaster, BOOL bLastP
 	// For color JPEG, you need to skip the header information of 623 bytes
 
     int iJpegHeaderSize = 623;
-#ifdef HAVB_LIBDL
+#ifdef HAVE_LIBDL
     if (HPLJJRCompress && m_eCompressMode == COMPRESS_MODE_LJ)
     {
         iJpegHeaderSize = 0;
@@ -906,7 +906,7 @@ DISPLAY_STATUS LJJetReady::ParseError(BYTE status_reg)
 BYTE *    ModeJPEG::fpJPEGBuffer = NULL;       // image buffer
 DWORD     ModeJPEG::fJPEGBufferPos;            // position of 1'st empty byte in image buffer
 
-void ModeJPEG::jpeg_flush_output_buffer_callback(BYTE* buffer, DWORD size)
+void ModeJPEG::jpeg_flush_output_buffer_callback(JOCTET *outbuf, BYTE* buffer, DWORD size)
 {
     fJPEGBufferPos += size;
     memcpy (fpJPEGBuffer, buffer, size);
@@ -941,6 +941,7 @@ BYTE* ModeJPEG::GetBuffer()
 extern "C"
 {
 void jpeg_buffer_dest (j_compress_ptr cinfo, JOCTET* outbuff, void* flush_output_buffer_callback);
+void hp_rgb_ycc_setup (int iFlag);
 }
 
 #define ConvertToGrayMacro(red, green, blue) ((unsigned char)( ( (red * 30) + (green * 59) + (blue * 11) ) / 100 ))
@@ -1105,7 +1106,6 @@ BOOL  ModeJPEG::Compress( HPLJBITMAP *pSrcBitmap,
                         ) 
 
 {
-
 #ifdef HAVE_LIBDL
     if (HPLJJRCompress && m_eCompressMode == COMPRESS_MODE_LJ)
     {
@@ -1116,6 +1116,19 @@ BOOL  ModeJPEG::Compress( HPLJBITMAP *pSrcBitmap,
         {
             return FALSE;
         }
+        if (bGrayscaleSet)
+        {
+            BYTE    *p = pSrcBitmap->pvBits;
+            for (int j = 0; j < pSrcBitmap->bitmapInfo.bmiHeader.biHeight; j++)
+            {
+                for (int i = 0; i < pSrcBitmap->bitmapInfo.bmiHeader.biWidth; i++)
+                {
+                    p[0] = ConvertToGrayMacro (p[0], p[1], p[2]);
+                    p[1] = p[2] = 0;
+                    p += 3;
+                }
+            }
+        }
         iRet = HPLJJRCompress (pTrgBitmap->pvBits, (uint32_t *) &pTrgBitmap->cjBits, pSrcBitmap->pvBits,
                                pSrcBitmap->bitmapInfo.bmiHeader.biWidth, pSrcBitmap->bitmapInfo.bmiHeader.biHeight);
         if (iRet < 0)
@@ -1134,6 +1147,8 @@ BOOL  ModeJPEG::Compress( HPLJBITMAP *pSrcBitmap,
 
 	fJPEGBufferPos = 0;
 
+    hp_rgb_ycc_setup (1);   // Use modified Mojave CSC table
+
     int iColorsUsed = bGrayscaleSet ? 1 : 3;
 
     //----------------------------------------------------------------
@@ -1725,7 +1740,7 @@ BOOL ModeJPEG::Process
 			// Convert 24bpp Gray to 8bpp Gray.
 			// JPEG takes K 8bpp gray data. We are using two different buffers for these.
 			//
-			if(bGrayScaleSet)
+			if(bGrayScaleSet && m_eCompressMode == COMPRESS_MODE_JPEG)
 			{
 				pbTemp = (BYTE*)m_SourceBitmap.pvBits;
         
@@ -1750,7 +1765,7 @@ BOOL ModeJPEG::Process
 			//
 			// JPEG grayscale specific operations are done here.
 			//
-			if(bGrayScaleSet)
+			if(bGrayScaleSet && m_eCompressMode == COMPRESS_MODE_JPEG)
 			{
 				jpegGrayBitmap.cjBits = m_SourceBitmap.cjBits / 3;
 				jpegGrayBitmap.bitmapInfo.bmiHeader.biSizeImage = m_SourceBitmap.bitmapInfo.bmiHeader.biSizeImage / 3;
@@ -1758,7 +1773,7 @@ BOOL ModeJPEG::Process
 				jpegGrayBitmap.bitmapInfo.bmiHeader.biWidth = m_SourceBitmap.bitmapInfo.bmiHeader.biWidth;
 				jpegGrayBitmap.bitmapInfo.bmiHeader.biHeight = m_SourceBitmap.bitmapInfo.bmiHeader.biHeight;
 			}
-			if (bGrayScaleSet)
+			if (bGrayScaleSet && m_eCompressMode == COMPRESS_MODE_JPEG)
 			{
 				bRet = Compress (&jpegGrayBitmap, &m_DestBitmap, &qTableInfo,bGrayScaleSet);
 			}
