@@ -71,10 +71,19 @@
 #include "pscript.h"
 #include "ljjetready.h"
 #include "ljfastraster.h"
-#ifdef APDK_LJZJS_MONO
+#if defined (APDK_LJZJS_MONO) || defined (APDK_LJZJS_COLOR) || defined (APDK_LJM1005)
 #include "ljzjs.h"
+#endif
+#ifdef APDK_LJZJS_MONO
 #include "ljzjsmono.h"
 #endif
+#ifdef APDK_LJM1005
+#include "ljm1005.h"
+#endif
+
+#ifdef APDK_QUICKCONNECT
+#include "quickconnect.h"
+#endif
 
 APDK_BEGIN_NAMESPACE
 
@@ -102,6 +111,10 @@ LJFastRasterProxy DeviceRegistry::s_LJFastRasterProxy;
 LJZjsMonoProxy DeviceRegistry::s_LJZjsMonoProxy;
 #endif
 
+#ifdef APDK_LJM1005
+LJM1005Proxy DeviceRegistry::s_LJM1005Proxy;
+#endif
+
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
 PSP100Proxy DeviceRegistry::s_PSP100Proxy;
 PSP470Proxy DeviceRegistry::s_PSP470Proxy;
@@ -188,6 +201,10 @@ Apollo21xxProxy DeviceRegistry::s_Apollo21xxProxy;
 Apollo2xxxProxy DeviceRegistry::s_Apollo2xxxProxy;
 #endif
 
+#ifdef APDK_QUICKCONNECT
+QuickConnectProxy DeviceRegistry::s_QuickConnectProxy;
+#endif
+
 DeviceRegistry::DeviceRegistry()
     : device(UNSUPPORTED)
 {
