@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,33 +19,47 @@
 # Author: Don Welch
 #
 
+# Std Lib
+import os.path
+
+# Local
 from base.g import *
 from base import utils
 from prnt import cups
-import os.path
+from ui_utils import load_pixmap
+
+# Qt
 from qt import *
 from nodevicesform_base import NoDevicesForm_base
 
+
+
 class NoDevicesForm(NoDevicesForm_base):
     def __init__(self,parent = None,name = None,modal = 0,fl = 0):
         NoDevicesForm_base.__init__(self,parent,name,modal,fl)
 
-        self.Icon.setPixmap(QPixmap(os.path.join(prop.image_dir, "warning.png")))
+        self.Icon.setPixmap(load_pixmap("warning.png", '32x32'))
+
 
     def CUPSButton_clicked(self):
         self.close()
         utils.openURL("http://localhost:631/admin?op=add-printer")
 
+
     def ExitButton_clicked(self):
         self.close()
 
+
     def setupPushButton_clicked(self):
         self.close()
         su_sudo = None
 
         if utils.which('kdesu'):
             su_sudo = 'kdesu -- %s'
-
+            
+        elif utils.which('gnomesu'):
+            su_sudo = 'gnomesu -c "%s"'
+            
         elif utils.which('gksu'):
             su_sudo = 'gksu "%s"'
 
@@ -76,5 +90,6 @@ class NoDevicesForm(NoDevicesForm_base):
                                     QMessageBox.NoButton,
                                     QMessageBox.NoButton)
 
+
     def __tr(self,s,c = None):
         return qApp.translate("NoDevicesForm",s,c)
